pub struct PendingReasonCounts {
pub completion_count: i64,
pub student_number_count: i64,
}Expand description
Live pending rows per blocker, for the surfaces that used to read the three states off the
ledger.
Fields
completion_count: i64student_number_count: i64Trait Implementations
Sourceimpl Clone for PendingReasonCounts
impl Clone for PendingReasonCounts
Sourcefn clone(&self) -> PendingReasonCounts
fn clone(&self) -> PendingReasonCounts
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for PendingReasonCounts
impl ComposeSchema for PendingReasonCounts
Sourceimpl Debug for PendingReasonCounts
impl Debug for PendingReasonCounts
Sourceimpl Default for PendingReasonCounts
impl Default for PendingReasonCounts
Sourcefn default() -> PendingReasonCounts
fn default() -> PendingReasonCounts
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PendingReasonCounts
impl<'de> Deserialize<'de> for PendingReasonCounts
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PendingReasonCounts
impl PartialEq for PendingReasonCounts
Sourceimpl Serialize for PendingReasonCounts
impl Serialize for PendingReasonCounts
Sourceimpl ToSchema for PendingReasonCounts
impl ToSchema for PendingReasonCounts
impl Copy for PendingReasonCounts
impl Eq for PendingReasonCounts
impl StructuralPartialEq for PendingReasonCounts